cmd

package
v1.5.4-0...-779767d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 24, 2026 License: MIT Imports: 34 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version = "3.0.1"

Functions

func Execute

func Execute() error

func GetClientFormat

func GetClientFormat(clientType ClientType) string

GetClientFormat returns the API format used by the client.

Types

type ClientType

type ClientType string

ClientType represents the type of client being used.

const (
	ClientClaude   ClientType = "claude"
	ClientCodex    ClientType = "codex"
	ClientOpenCode ClientType = "opencode"
)

func GetClientType

func GetClientType(clientBin string) ClientType

GetClientType returns the client type from the binary name.

Directories

Path Synopsis
opencc-migrate is a standalone migration tool published as the "opencc" v2.0.0 binary.
opencc-migrate is a standalone migration tool published as the "opencc" v2.0.0 binary.

Jump to